@@ -11,8 +11,13 @@ if LIBMBD_PREFIX == '':
     def build(setup_kwargs):
         pass
 
-
 else:
+
+    # some Conda environments do not add their include dir into default includes
+    CONDA_PREFIX = os.environ.get('CONDA_PREFIX')
+    if not LIBMBD_PREFIX and CONDA_PREFIX:
+        LIBMBD_PREFIX = CONDA_PREFIX
+
     if LIBMBD_PREFIX:
         ext_kwargs = {
             'include_dirs': [f'{LIBMBD_PREFIX}/include'],
@@ -23,7 +28,7 @@ else:
         ext_kwargs = {}
     ffibuilder = cffi.FFI()
     ffibuilder.set_source(
-        'pymbd._libmbd', '#include "mbd.h"', libraries=['mbd'], **ext_kwargs
+        'pymbd._libmbd', '#include "mbd/mbd.h"', libraries=['mbd'], **ext_kwargs
     )
     with open(MBD_H) as f:
         ffibuilder.cdef(f.read())
